<?php

namespace App\Console\Commands;

use App\Models\Reservation;
use App\Models\Restaurant;
use App\Models\Table;
use Illuminate\Console\Command;

class AssignReservationTable extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'app:assign-reservation-table';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Check for next 1 hour reservation tables and change the status of the table accordingly';

    /**
     * Execute the console command.
     */
    public function handle()
    {
        // Get restaurant timezone and calculate time range
        $timezone = Restaurant::value('timezone');
        $now = now($timezone);

        // Update table status for reservations in next hour in a single query
        Table::whereIn('id', function ($query) use ($now) {

            $start = $now->toDateTimeString();
            $end = $now->addHour()->toDateTimeString();

            $query->select('table_id')
                ->from('reservations')
                ->whereNotNull('table_id')
                ->whereBetween('reservation_date_time', [$start, $end]);
        })->update(['available_status' => 'reserved']);
    }
}
